@@ -6,219 +6,131 @@
 # File::Copy::Recursive & friends -- yeah, ancient.
 
 package Module::FromPerlVer;
-use 5.006;
+use 5.008;
 use strict;
 use version;
 
-use NEXT;
+use Cwd                     qw( getcwd          );
+use File::Basename          qw( basename        );
+use File::Copy::Recursive   qw( dircopy         );
+use File::Find              qw( find            );
+use File::Spec::Functions   qw( &catpath        );
+use FindBin                 qw( $Bin            );
+use List::Util              qw( first reduce    );
+use Symbol                  qw( qualify_to_ref  );
 
-use Cwd                     qw( cwd                     );
-use File::Basename          qw( basename                );
-use File::Copy::Recursive   qw( dircopy                 );
-use File::Find              qw( find                    );
-use FindBin                 qw( $Bin                    );
-use List::Util              qw( first                   );
-use Scalar::Util            qw( blessed                 );
-use Symbol                  qw( qualify qualify_to_ref  );
+use File::Spec::Functions
+qw
+(
+    &abs2rel
+    &rel2abs
 
-use Module::FromPerlVer::Dir;
+    &catdir
+    &catpath
+    &splitpath
+);
 
 ########################################################################
 # package variables & sanity checks
 ########################################################################
 
-our $VERSION    = version->parse( '0.0.5' )->numify;
+our $VERSION    = version->parse( 'v0.2.0' )->numify;
 
-my %defaultz = 
-(
-    # pick your poison
+my $default_d   = 'version';
 
-    default_use     => 'dir',
-    use_dir         => '',
-    use_git         => '',
-
-    # global settings
-
-    perl_version    => '',
-    version_from    => '',
-    verbose         => '',
-
-    # directory
-
-    version_dir     => 'version',
-
-    # git
-
-    git_prefix      => 'perl/',
-);
+my $cwd         = getcwd;
 
 ########################################################################
 # utility subs
 ########################################################################
 
-my $extract_args
-= sub
-{
-    my ( undef, %argz ) = @_;
-
-    while( my ($k, $def_v) = each %defaultz )
-    {
-        my $env_k   = uc $k;
-        my $env_v   = $ENV{ $env_k };
-
-        for( $argz{ $k } )
-        {
-            if( defined $env_v )
-            {
-                print "# Env: $k = '$env_v' ($env_k)";
-
-                $argz{ $k } = $env_v;
-            }
-            elsif( defined $argz{ $k } )
-            {
-                print "# Arg: $k = '$_'";
-            }
-            elsif( $def_v )
-            {
-                print "# Def: $k = '$def_v'";
-
-                $argz{ $k } = $def_v;
-            }
-            else
-            {
-                # nothing more to do: the default
-                # isn't overridden and it false,
-                # no argument supplied: skip it.
-            }
-        }
-    }
-
-    \%argz
-};
-
-my $make_extract
-= sub
-{
-    my $argz    = shift;
-
-    my @found 
-    = map
-    {
-        m{ (use_ ([a-z]+) ) }x && delete $argz->{ $1 }
-        ? $2
-        : ()
-    }
-    keys %$argz;
-
-    local $, = ' ';
-
-    if( @found > 1 )
-    {
-        die "Invalid: Multiple sources, @found\n";
-    }
-    elsif( @found )
-    {
-        # nothing more do do
-    }
-    else
-    {
-        push @found, delete $argz->{ default_use };
-    }
-
-    my $type    = ucfirst $found[0];
-    my $pkg     = qualify $type;
-
-    $argz->{ type } = $type;
-
-    print "# Extract with: '$type' ($pkg)";
-
-    $pkg->new( $argz )
-};
-
-my $extract_perl_v
-= sub
-{
-    my $extract = shift;
-    my $perl_v  = '';
-
-    if( $perl_v = $extract->value( 'perl_version' ) )
-    {
-        eval
-        {
-            version->parse( $perl_v )->numify
-        }
-        or 
-        die "Unparsable perl version: '$perl_v'\n"
-    }
-    elsif( my $path = $extract->{ version_from } )
-    {
-        -e $path or die "Bogus version_from: non-existant '$path'\n";
-        -f _     or die "Bogus version_from: non-file     '$path'\n";
-        -s _     or die "Bogus version_from: zero-size    '$path'\n";
-        -r _     or die "Bogus version_from: non-readable '$path'\n";
-
-        # at this point the version file seems minimally usable.
-
-        open my $fh, '<', $path
-        or
-        die "Botched version_from: open '$path', $!\n";
-
-        $perl_v
-        = first
-        {
-            if
-            (
-                my ( $min_v )
-                = m{ \buse \s+ (v? 5[.] +?) \s* ; }
-            )
-            {
-                $perl_v 
-                = version->parse( $min_v )->numify
-                or 
-                die "Invalid version string: '$_' ($path)"
-            }
-            elsif
-            (
-                my ( $max_v ) 
-                = m{ \bno  \s+ (v? 5[.] +?) \s* ; }
-            )
-            {
-                $perl_v
-                = version->parse( $max_v )->numify - 0.000001
-                or 
-                die "Invalid version string: '$_' ($path)"
-            }
-            else
-            {
-                ''
-            }
-        }
-        readline $fh
-        or
-        die "Bogus version_from: '$path' lacks '(use|no) version'.\n";
-    }
-    else
-    {
-        # this *should* always be parseable.
-
-        $perl_v = version->parse( $^V )->numify
-        or
-        die "Severe weirdness: unparsable \$^V ($^V).\n";
-    }
-
-    $extract->value( perl_version => $perl_v )
-};
-
 my @handlerz = 
 (
     sub
     {
-        # acquire running perl version.
+        # set running perl version.
 
-        my $extract = shift;
-        my $perl_v  = $extract->$extract_perl_v;
+        my $argz    = shift;
+        my $path    = $argz->{ version_from } || '';
+        my $perl_v  = '';
 
-        # lacking an exception, we have a perl version.
+        if( my $value = $ENV{ PERL_VERSION } )
+        {
+            warn "Overriding '$path' with PERL_VERSION='$value'.\n"
+            if $path;
+
+            $perl_v = version->parse( $value )->numify
+            or
+            die "Botched version_from: invalid '$value' from PERL_VERSION.\n";
+        }
+        elsif( $path )
+        {
+            -e $path or die "Bogus version_from: non-existant '$path'\n";
+            -f _     or die "Bogus version_from: non-file     '$path'\n";
+            -s _     or die "Bogus version_from: zero-size    '$path'\n";
+            -r _     or die "Bogus version_from: non-readable '$path'\n";
+
+            # at this point the version file seems minimally usable.
+
+            my $found
+            = do
+            {
+                open my $fh, '<', $path
+                or
+                die "Botched version_from: open '$path', $!\n";
+
+                first
+                {
+                    if
+                    (
+                        my ( $min_v )
+                        = m{ \b use \s+ (v?5[.][.\d_]*)}x
+                    )
+                    {
+                        $perl_v 
+                        = version->parse( $min_v )->numify
+                        or 
+                        die "Invalid version string: '$_' ($path)"
+                    }
+                    elsif
+                    (
+                        my ( $max_v ) 
+                        = m{ \b no  \s+ (v?5[.][.\d_]*)}x
+                    )
+                    {
+                        $perl_v
+                        = version->parse( $max_v )->numify - 0.000001
+                        or 
+                        die "Invalid version string: no '$_' ($path)"
+                    }
+                    else
+                    {
+                        ''
+                    }
+                }
+                grep
+                {
+                    /\S/
+                }
+                readline $fh
+                or
+                die "Bogus version_from: '$path' lacks 'use version'.\n";
+            };
+        }
+        else
+        {
+            # this *should* to be parseable.
+
+            $perl_v = version->parse( $^V )->numify
+            or
+            die "Severe weirdness: unparsable \$^V ($^V).\n";
+
+        }
+
+        # belt & suspenders time
+
+        $perl_v
+        or die "Broken perl_version: no version extracted.";
 
         *{ qualify_to_ref 'perl_version' }
         = sub 
@@ -226,79 +138,155 @@ my @handlerz =
             $perl_v
         };
 
-        print '# Perl version: ' . perl_version();
+        print "# Perl version: '$perl_v'\n";
 
         return
     },
 
     sub
     {
-        # extract source of the inputs. this will be
-        # either the ./version directory or a git tag
-        # prefix.
+        # exract version parent directory
 
-        my $extract = shift;
-        my $prefix  = $extract->source_prefix;
+        my $argz    = shift;
+        my $vers_d  = $argz->{ version_dir } || $default_d;
 
-        *{ qualify_to_ref 'source_prefix' }
-        = sub
+        my ( $vol, $dir )   = splitpath $vers_d, 1;
+
+        # $Bin/$dir simplifies testing by locating './t/version'
+        # for anything running in ./t using only the default.
+
+        my $path
+        = first
         {
-            $prefix
-        };
-
-        print '# Source prefix: ' . source_prefix();
-
-        return
-    },
-
-    sub
-    {
-        # locate source appropriate for perl version.
-
-        my $extract = shift;
-        my $perl_v  = perl_version();
-
-        my @sourcz  = $extract->module_sources
-        or die "Botched module_sources: empty source list.\n";
-
-        my $found
-        =first
-        {
-            $perl_v >= $_->[0]
-        }
-        sort
-        {
-            $b->[0] <=> $a->[0]
+            -d
         }
         map
         {
-            [
-                version->parse( basename $_ )->numify,
-                $_
-            ]
+            my $d   = catdir $_, $dir;
+
+            catpath $vol, $d, ''
         }
-        @sourcz
-        or do
-        {
-            local $,    = "\n#\t";
+        (
+            '',
+            $cwd,
+            $Bin,
+        )
+        or
+        die "Bogus version_dir: Non-existant: '$dir'.\n";
 
-            die 'Botched module_source: no appropriate version',
-            @sourcz, "\n";
-        };
+        # first, above, guarantees that this is the last
+        # dir examined. make the final sanity checks.
 
-        my ( $mod_v, $path ) = @$found;
+        -r _        or die "Bogus version_dir: non-readable '$path'";
+        -w _        or die "Bogus version_dir: non-writeable '$path'";
+        -x _        or die "Bogus version_dir: non-execable '$path'";
 
-        print "# Module version: $mod_v <= $perl_v";
+        index $path, $cwd
+        or
+        $path   = abs2rel $path, $cwd;
 
-        $extract->value( module_source => $path );
+        my @found   = glob "$path/*"
+        or die "Botchd version_dir: '$path' is empty directory.\n";
 
-        *{ qualify_to_ref 'module_source' }
+        *{ qualify_to_ref 'version_dir' }
         = sub
         {
             $path
         };
 
-        print '# Module source: ' . module_source();
+        print "# Version directory: '$path'\n";
+
+        return
+    },
+
+    sub
+    {
+        # locate source dir supporting perl version.
+
+        my $perl_v      = perl_version();
+        my $version_d   = version_dir();
+
+        # klutzy as this looks it beats a sort on $_->[0]
+        # followed by first.
+
+
+        my $found
+        = reduce
+        {
+            # i.e., from any dir with version <= perl_v
+            # prefer the one with the highest verison.
+            # equality handles differences in version 
+            # format colliding on a single numified value.
+
+            $perl_v < $b->[0]
+            ? $a
+            : $a->[0] >= $b->[0]
+            ? $a
+            : $b
+        }
+        (
+            # sentinel allows evaluating all version dir's
+            # for <= $perl_v.
+
+            [ 0, '' ],
+            map
+            {
+                my $dir_v   
+                = eval
+                {
+                    version->parse( basename $_ )->numify
+                }
+                or warn "Unusable version dir: '$_', not parsable.\n";
+
+                $dir_v
+                ? [ $dir_v, $_ ]
+                : ()
+            }
+            glob "$version_d/*"
+        );
+
+        $found->[0]
+        or 
+        die "Failed version dir: all '$version_d' > $perl_v\n";
+
+        my $source_d    = $found->[ -1 ];
+
+        *{ qualify_to_ref 'source_dir' }
+        = sub
+        {
+            $source_d
+        };
+
+        print "# Source directory:  '$source_d'\n";
+
+        return
+    },
+
+    sub
+    {
+        # set the destination directory.
+
+        my $argz    = shift;
+        my $dest_d  = $argz->{ dest_dir } || $cwd;
+
+        -e $dest_d  or die "Botched dest_dir: non-existant '$dest_d'";
+        -d _        or die "Botched dest_dir: non-directory '$dest_d'";
+        -r _        or die "Botched dest_dir: non-readable '$dest_d'";
+        -w _        or die "Botched dest_dir: non-writeable '$dest_d'";
+
+        index $dest_d, $cwd
+        or
+        $dest_d     = abs2rel $dest_d, $cwd;
+
+        # looks minimally usable...
+
+        *{ qualify_to_ref 'dest_dir' }
+        = sub
+        {
+            $dest_d
+        };
+
+        print "# Dest dir: '$dest_d'.\n";
 
         return
     },
@@ -310,89 +298,143 @@ my @handlerz =
         # pre-assigning the hashref's simplifies dealing
         # with a collection of empty dir's.
 
-        my $extract = shift;
-        my $ref     = qualify_to_ref 'source_files';
+        my $source_d    = source_dir();
+        my @pathz       = ( [], [] );
 
-        if( my @pathz   = $extract->source_files )
+        my $n           = length $source_d;
+
+        find
+        sub
         {
-            *$ref
-            = sub
-            {
-                wantarray
-                ? @pathz
-                : $pathz[0]
-            };
+            my $path    = $File::Find::name;
 
-            local $,    = "\n#\t";
-            print '# Source files:', @{ scalar source_files() };
-        }
-        else
-        {
-            *$ref
-            = sub
-            {
-                # avoid returning true in scalar context
+            $path eq $source_d
+            and return;
 
-                return
-            };
+            my $is_dir  
+            = -d 
+            ? 1
+            : 0
+            ;
 
-            print '# No source files.';
-        }
+            my ( $vol, $dir, $base )
+            = splitpath $path, $is_dir;
 
-        return
-    },
+            my $sub_d   = abs2rel $dir, $source_d;
 
-    sub
-    {
-        my $ref = qualify_to_ref 'cleanup';
+            push @{ $pathz[ $is_dir ] }, catpath $vol, $sub_d, $base;
+        },
+        $source_d;
 
-        if( my ( $filz, $dirz ) = source_files() )
-        {
-            *$ref
-            = sub
-            {
-                unlink @$filz;
+        # deal with a set of empty dirs.
 
-                -e $_ && warn "Failed removal: '$_'"
-                for @$filz;
+        @{ $pathz[0] }
+        or warn "No input files found: '$source_d'";
 
-                # i.e., don't clobber dir's which have any
-                # files we didn't copy in them. this is most
-                # likely for ./t which can have common tests.
-
-                for my $dir ( @$dirz )
-                {
-                    ( my @a = glob "$dir/*" )
-                    or 
-                    rmdir $dir;
-                }
-
-                return
-            };
-
-            print '# Install cleanup.';
-        }
-        else
-        {
-            *$ref   = sub{};
-
-            print '# Nothing to clean up.';
-        }
-
-        return
-    },
-
-    sub
-    {
-        my $extract = shift;
-
-        *{ qualify_to_ref 'get_files' }
+        *{ qualify_to_ref 'source_paths' }
         = sub
         {
-            $extract->get_files
+            wantarray
+            ? @pathz
+            : $pathz[0]
         };
 
-        print "# Get files with: '$extract->{ type }'";
+        local $,    = "\n#\t";
+        print '# Source files:', @{ $pathz[0] }, "\n";
+
+        return
+    },
+
+    sub
+    {
+        my ( $dst_v, $dst_d )   = splitpath dest_dir(), 1;
+        my ( $filz, $dirz   )   = source_paths();
+
+        my @dst_filz
+        = map
+        {
+            my ( undef, $src_d, $base ) = splitpath $_;
+
+            catpath $dst_v, catdir( $dst_d, $src_d ), $base;
+        }
+        @$filz;
+
+        my @dst_dirz
+        = map
+        {
+            my ( undef, $dir, undef ) = splitpath $_, 1;
+
+            catpath $dst_v, catdir( $dst_d, $dir ), '';
+        }
+        @$dirz;
+
+        for( @dst_filz, @dst_dirz )
+        {
+            index $_, $cwd
+            and
+            $_  = abs2rel $_, $cwd
+        }
+
+        *{ qualify_to_ref 'dest_paths' }
+        = sub
+        {
+
+            wantarray
+            ? ( \@dst_filz, \@dst_dirz )
+            :   \@dst_filz
+        };
+    },
+
+    sub
+    {
+        *{ qualify_to_ref 'cleanup' }
+        = sub
+        {
+            my ( $filz, $dirz ) = dest_paths();
+
+            unlink @$filz;
+
+            -e $_ && warn "Failed removal: '$_'"
+            for @$filz;
+
+            # i.e., don't clobber dir's which have any
+            # files we didn't copy in them. this is most
+            # likely for ./t which can have common tests.
+
+            for my $dir ( @$dirz )
+            {
+                ( my @a = glob "$dir/*" )
+                or 
+                rmdir $dir;
+            }
+        };
+
+        return
+    },
+
+    sub
+    {
+        my ( $filz, $dirz ) = source_paths();
+        my $dest_d          = dest_dir();
+        my $expect  = 1 + @$filz + @$dirz;
+
+        *{ qualify_to_ref 'copy_source_dir' }
+        = sub
+        {
+            my $src     = source_dir();
+            my $dst     = dest_dir();
+            my $found   = dircopy $src, $dst;
+            
+            print "# Copied: $found files from '$src'\n";
+
+            $found != $expect
+            and
+            warn "# Oddity: mismatched count $found != $expect.\n";
+
+            $found
+        };
+
+        print "# Expect: $expect files to be copied.\n";
 
         return
     }
@@ -404,22 +446,25 @@ my @handlerz =
 
 sub import
 {
-    local $\    = "\n";
+    my ( undef, %argz ) = @_;
 
-    my $argz    = &$extract_args;
-    my $extract = $make_extract->( $argz );
-
-    $extract->$_ for @handlerz;
+    for my $sub ( @handlerz )
+    {
+        $sub->( \%argz );
+    }
 
     # at this point the args are consumed and if we are 
-    # still alive the utility subs are installed.
+    # still alive the copy function has been installed.
     #
-    # Note: this returns true if the handler cycle completed
-    # (either no_copy value or result of making the copy).
+    # caller can use cleanup() to remove files copied or 
+    # source_paths() to get a list of them.
+    #
+    # this returns the count from File::Copy::Recursive,
+    # which should be true if anything was found to copy.
 
-    $extract->{ no_copy }
+    $argz{ no_copy }
     or
-    get_files()
+    copy_source_dir()
 }
 
 # keep require happy
@@ -474,16 +519,10 @@ Module::FromPerlVer - install modules compatible with the running perl.
 
     # this can be useful for regression testing earlier 
     # versions of modules against the running version 
-    # (e.g., validating experimental features, benchmarking
-    # older code against newer perl executables).
-    #
-    # arguments can be passed to use or set in the environment
-    # with a variable of the option uppercased. For example:
+    # (e.g., validating experimental features).
 
     $ PERL_VERSION='5.024002' perl Makefile.PL;
 
-    use Module::FromPerlVer qw( perl_version v5.24.1 );
-
     # use a file to determine the perl version.
     # this takes the use-ed version from the file
     # to set the expected perl version (e.g., to 
@@ -491,8 +530,6 @@ Module::FromPerlVer - install modules compatible with the running perl.
 
     use Module::FromPerlVer   qw( version_from ./lib/foobar.pm );
 
-    VERSION_FROM='./lib/foobar.pm' use Module::FromPerlVer;
-
     # or a one-line datafile.
     # "use vX.Y.Z" will find up to that version, "no vX.Y.Z" will 
     # use up to that version minus '0.000001'.
@@ -511,18 +548,7 @@ Module::FromPerlVer - install modules compatible with the running perl.
     # maybe you don't like the name 'version', you
     # prefer "history" instead.
 
-    use Module::FromPerlVer   qw( source_prefix history );
-
-    # maybe you don't like storing your older versions in 
-    # a directory, you prefer to use git with tags to snag
-    # the working directory with a default tag prefix of 
-    # "perl/":
-
-    use Module::FromPerlVer qw( use_git 1 );
-
-    # use ThingyDotNet/<perl version> as the git tag:
-
-    use Module::FromPerlVer qw( source_prefix ThingyDotNet/ );
+    use Module::FromPerlVer   qw( version_dir history );
 
     # set up everything but skip making the copy.
     #
@@ -534,14 +560,14 @@ Module::FromPerlVer - install modules compatible with the running perl.
 
     use Module::FromPerlVer   qw( no_copy 1 );
 
-    my ( $filz, $dirz ) = Module::FromPerlVer::source_files;
+
+    my ( $filz, $dirz ) = Module::FromPerlVer::source_paths;
 
     Module::FromPerlVer->copy_source_dir;
 
     my $madness = 'Module::FromPerlVer';
-    my $method  = 'cleanup';
 
-    $madness->$method;
+    $madness->cleanup;
 
 
 
@@ -557,11 +583,8 @@ for $^V are necessary.
 
 =head2 Using the module
 
-Using this module requires two things: The module and a source
-for perl-version-speific files. With "use_dir" the files are
-found in a specific local directory; with "use_git" the are
-found via (guess... if you said "cvs checkout from ./attic"
-you'd be wrong).
+Using this module requires two things: The module and a local
+filesysem labeled by compatible Perl version.
 
 =over 4
 
@@ -583,24 +606,11 @@ files are suitable for that version of perl. Common
 examples are README, MANIFEST, Changes, ./lib, ./t,
 ./bin.
 
-=item Version Tag
-
-With git the current repository is scanned via "git tags"
-with the source prefix. The versions need to look path-ish:
-
-    perl/v5.6.1
-    Perly/5.005003
-    MyPerlStuff/v5.24
-
-will all do nicely: they have a '/' with a "basename" of
-a parsable perly version.
-
 =item Basic Use
 
 Using the module in setup code (e.g., Makefile.PL):
 
-    use Module::FromPerlVer;
-    use Module::FromPerlVer qw( use_dir 1 );
+    use Module::FromPerlVer
 
 will look in the ./version directory, sort the subdir's 
 in numerically decreasing order by version (see version)
@@ -663,9 +673,9 @@ specific version of perl:
 
     for i in ./version/*
     do
-        COMPATIBLE_VERSION="$(basename $i)" \
-        $perl Makefile.PL                   &&
-        make all test                       ;
+        PERL_VERSION="$(basename $i)"   \
+        $perl Makefile.PL               &&
+        make all test                   ;
     done
 
 =item use Module::FromPerlVer ( version_from => $path );
@@ -680,7 +690,7 @@ with a specific release of the module.
 
 =item Overriding "version".
 
-If you hate the name "version", use "version_dir" to set it:
+Say you hate the name version:
 
     use Module::FromPerlVer qw( version_dir history );
 
@@ -699,58 +709,6 @@ below) but will not execute copy_source_dir().
 
 =back
 
-=head2 Use Messages
-
-The module supplies most of the information necessary to 
-debug environment and configuration issues when import()
-is called:
-
-    # Def: default_use = 'dir'
-    # Def: version_dir = 'version'
-    # Def: git_prefix = 'perl/'
-    # Extract with: 'Dir' (Module::FromPerlVer::Dir)
-    # Perl version: 5.026001
-    # Source prefix: ./t/version
-    # Module version: 5.005003 <= 5.026001
-    # Module source: ./t/version/5.005003
-    # Source files:
-    #   ./lib/Foo.pm
-    #   ./pod/Foo.pod
-    #   ./etc/version.dat
-    # Install cleanup.
-    # Get files with: 'Dir'
-
-
-=over 4
-
-=item Configuration
-
-    # Def: default_use = 'dir'
-    # Def: version_dir = 'version'
-    # Def: git_prefix = 'perl/'
-
-There are three variants: 'Def', 'Env', 'Arg' which 
-show where the values came from. 
-
-=item Handler
-
-This shows which of use_* or the default_use was
-chosen for the copy handler. In this case the 
-default_use value of 'dir' provided the source:
-
-    # Extract with: 'Dir' (Module::FromPerlVer::Dir)
-
-=item Utility Installation
-
-When the utility subs are installed they provide 
-basic information about the values selected from
-the arguments, perl version, and workspace.
-
-See "Utility Subs" (below) for more information on
-what these mean.
-
-=back
-
 =head2 Utility Subs
 
 A few utility sub's are installed into Module::FromPerlVer 
@@ -793,27 +751,21 @@ paths with the identical effect:
 Returns the parsed, numified Perl version value (see 
 version module).
 
-=item version_source()
+=item version_dir()
 
-Returns the source of the version directory
-(e.g., dir "version" or tag "perl/").
+Returns the basename of the version directory
+(i.e., default 'version').
 
-=item version_source()
+=item source_dir()
 
-The subdir or tag from which the files are sourced. This will 
-be a relative path from $FindBin::Bin, including the 
-version directory:
+The subdir from which the files are sourced. This will be a
+relative path from $FindBin::Bin, including the version 
+directory:
 
     ./version/5.006001
     ./version/v5.24.2
 
-    perl/v5.24
-    perl5.005_003
-
-=item source_files()
-
-For directory source only (i.e., where the files can be 
-looked up easily beforehand):
+=item source_paths()
 
 Used in a scalar context this returns an arrayref of relative
 paths to files copied from the source_dir into the working 
@@ -824,9 +776,28 @@ files one of the directories. The former is used with unlink
 in cleanup to remove only the files that were copied; the 
 latter is used to rmdir empty directories.
 
-=item get_files()
+=item dest_dir()
 
-This executes the copy/checkout of source files.
+Note: Used mainly for testing.
+
+Returns the dest_dir used to copy source_paths.
+
+It mainly allows parallel testing without the tests overwriting one 
+another's output. Might also be useful to install files in a blib 
+directory during testing.
+
+=item dest_paths()
+
+Note: Used mainly for testing.
+
+Returns the source_paths() with the destination directory
+prefixed. In the default case this will map "./version/X/lib/foo.pm"
+to "./lib/foo.pm". If the dest_dir is, say, a tempdir then the
+dest paths will look like "./sandbox/10-frobnicate-asdf/lib/foo.pm".
+
+=item copy_source_dir()
+
+This executes the copy of all source files into '.'.
 
 Note: If import is called with "no_copy" and a true
 value then this will have to be called, see examples
@@ -834,35 +805,16 @@ for calling convention, above.
 
 =item cleanup()
 
-For Dir this removes the files copied, empty dir's left behind. This 
-approach allows for some files to be re-used across multiple releases 
-without getting clobbered by cleanup.  Likely examples are common 
-tests (i.e., t/*.t) or a MANIFEST for modules which have all of the 
-same files in each version.
+This first executes an unlink the files, then walks the 
+dir's executing rmdir on the empty ones.
 
-For Git this checks out whatever branch was in use when copy_files() 
-was called. That's the best guess I have for what was in use at the
-time a verion-specific tag was checked out.
+This approach allows for some files to be re-used across 
+multiple releases without getting clobbered by cleanup.
+Likely examples are common tests (i.e., t/*.t) or a MANIFEST
+for modules which have all of the same files in each version.
 
 =back
 
-=head1 NOTES
-
-=over 4
-
-=item Q: Why tags, not branches?
-
-A given brach may have un-tested updates on it. At that point it
-is not safe to assume HEAD will always work; at *that* point there
-isn't any good way to automatically checkout a given branch.
-
-Tags are static, can be assigned by the developer for specific
-commits, and can be re-assigned as necessary if code is updated.
-
-This also saves a whole lot of separate branches for version-
-specific generations of code. Just leave them in master -- or
-wherever you work -- with the tags behind.
-
 =back
 
 =head1 SEE ALSO
@@ -877,14 +829,14 @@ Perl versions.
 
 =item File::Copy::Recursive
 
-Describes how the files are copied by Dir.pm.
+Describes how the files are copied.
 
 =back
 
 =head1 LICENSE
 
 This code is licensed under the same terms as Perl-5.26 or any
-later released version of Perl.
+later released version of Perl the user preferrs.
 
 =head1 COPYRIGHT
 
